import 'package:flutter/material.dart';
import 'package:movies_app/common/constants/size_constants.dart';
import 'package:movies_app/presentation/widgets/app_dialog.dart';
import 'package:movies_app/presentation/widgets/logo.dart';
import 'package:movies_app/common/extensions/size_extension.dart';
import 'package:wiredash/wiredash.dart';

import 'navigation_expanded_list_item.dart';
import 'navigation_list_item.dart';

class NavigationDrawer extends StatelessWidget {
  const NavigationDrawer();

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        boxShadow: [
          BoxShadow(
            color: Theme.of(context).primaryColor.withOpacity(0.7),
            blurRadius: 4,
          ),
        ],
      ),
      width: Sizes.dimen_200.w,
      child: SafeArea(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: EdgeInsets.only(
                top: Sizes.dimen_8.h,
                bottom: Sizes.dimen_18.h,
                left: Sizes.dimen_8.w,
                right: Sizes.dimen_8.w,
              ),
              child: Logo(
                height: Sizes.dimen_20.h,
              ),
            ),
            NavigationListItem(
              title: 'Favorite Movies',
              onPressed: () {},
            ),
            NavigationListItem(
              title: 'Feedback',
              onPressed: () {
                Navigator.of(context).pop();
                Wiredash.of(context).show();
              },
            ),
            NavigationListItem(
              title: 'About',
              onPressed: () {
                Navigator.of(context).pop();

                _showDialog(context);
              },
            ),
            NavigationListItem(
              title: 'Request a Movie',
              onPressed: () {},
            )
          ],
        ),
      ),
    );
  }
}

void _showDialog(BuildContext context) {
  showDialog(
    context: context,
    builder: (BuildContext context) {
      return Container(
          child: AppDialog(
        title: 'About',
        description: 'This app is made with love in Flutter by',
        buttonText: 'okay',
        image: Image.asset(
          'assets/pngs/appscave.png',
          height: Sizes.dimen_32.h,
        ),
      ));
    },
  );
}
